@@ -3,41 +3,28 @@
 ### -------------------------------------------------------------------------
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Constructor 
+### Constructor
 ###
 
 .SerialParam_prototype <- c(
     list(
-        workers = 1L,
-        threshold="INFO",
-        logdir=NA_character_
+        workers = list(FALSE)
     ),
     .BiocParallelParam_prototype
 )
 
-.SerialParam <- setRefClass("SerialParam",
+.SerialParam <- setRefClass(
+    "SerialParam",
     contains="BiocParallelParam",
-    fields=list(
-        logdir="character"
-    ),
-    methods=list(
-        show = function() {
-            callSuper()
-            cat("  bplogdir: ", bplogdir(.self), "\n", sep="")
-        })
 )
 
 SerialParam <-
-    function(catch.errors=TRUE, stop.on.error = TRUE,
+    function(stop.on.error = TRUE,
              log=FALSE, threshold="INFO", logdir=NA_character_,
              progressbar=FALSE)
 {
-    if (!missing(catch.errors))
-        warning("'catch.errors' is deprecated, use 'stop.on.error'")
-
     prototype <- .prototype_update(
         .SerialParam_prototype,
-        catch.errors=catch.errors,
         stop.on.error=stop.on.error,
         log=log, threshold=threshold, logdir=logdir,
         progressbar=progressbar
@@ -51,43 +38,52 @@ SerialParam <-
 ### Methods - control
 ###
 
-setMethod("bpworkers", "SerialParam", function(x) 1L)
+setMethod(
+    "bpbackend", "SerialParam",
+    function(x)
+{
+    bpworkers(x)
+})
 
-setMethod("bpisup", "SerialParam", function(x) TRUE)
+setMethod(
+    "bpstart", "SerialParam",
+    function(x, ...)
+{
+    x$workers <- list(TRUE)
+    .bpstart_impl(x)
+})
+
+setMethod(
+    "bpstop", "SerialParam",
+    function(x)
+{
+    x$workers <- list(FALSE)
+    .bpstop_impl(x)
+})
+
+setMethod(
+    "bpisup", "SerialParam",
+    function(x)
+{
+    identical(bpbackend(x), list(TRUE))
+})
 
 setReplaceMethod("bplog", c("SerialParam", "logical"),
     function(x, value)
 {
-    x$log <- value 
+    x$log <- value
     validObject(x)
     x
 })
 
-setReplaceMethod("bpthreshold", c("SerialParam", "character"),
+setReplaceMethod(
+    "bpthreshold", c("SerialParam", "character"),
     function(x, value)
 {
     x$threshold <- value
     x
 })
 
-setMethod("bplogdir", "SerialParam",
-    function(x)
-{
-    x$logdir
-})
-
-setReplaceMethod("bplogdir", c("SerialParam", "character"),
-    function(x, value)
-{
-    if (!length(value))
-        value <- NA_character_
-    x$logdir <- value 
-    if (is.null(msg <- .valid.SnowParam.log(x))) 
-        x
-    else 
-        stop(msg)
-})
-
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Methods - evaluation
 ###
@@ -125,7 +121,7 @@ setMethod("bplapply", c("ANY", "SerialParam"),
 
     if (any(idx)) {
         BPREDO[idx] <- res
-        res <- BPREDO 
+        res <- BPREDO
     }
 
     if (!all(bpok(res)))
