@@ -29,7 +29,7 @@
 }
 
 .redo_index <-
-    function(X, BPREDO, verbose=TRUE)
+    function(X, BPREDO)
 {
     idx <- !bpok(BPREDO)
     if (length(idx)) {
@@ -37,8 +37,6 @@
             stop("'length(BPREDO)' must equal 'length(X)'")
         if (!any(idx))
             stop("no previous error in 'BPREDO'")
-        if (verbose)
-            message("resuming previous calculation ... ")
     }
     idx
 }
@@ -68,7 +66,7 @@
 .prettyPath <- function(tag, filepath)
 {
     wd <- options('width')[[1]] - nchar(tag) - 6
-    if(is.na(filepath))
+    if (length(filepath) == 0 || is.na(filepath))
         return(sprintf("%s: %s", tag, NA_character_))
     if (0L == length(filepath) || nchar(filepath) < wd)
         return(sprintf("%s: %s", tag, filepath))
@@ -97,3 +95,16 @@
 
     ddd
 }
+
+.dir_valid_rw <-
+    function(x)
+{
+    all(file.access(x, 6L) == 0L)
+}
+
+.stop <- function(...) {
+    msg <- paste(
+        strwrap(paste0("\n", ...), indent = 2, exdent = 2), collapse="\n"
+    )
+    stop(msg, call. = FALSE)
+}
